import type { Encryption } from '@adonisjs/encryption';
import type { Application } from '@adonisjs/application';
import type { Qs } from '../qs.js';
import { Route } from './route.js';
import { RouteGroup } from './group.js';
import { BriskRoute } from './brisk.js';
import { RouteResource } from './resource.js';
import type { LazyImport } from '../types/base.js';
import { LookupStore } from './lookup_store/main.js';
import { RouteMatchers as Matchers } from './matchers.js';
import type { MiddlewareAsClass, ParsedGlobalMiddleware } from '../types/middleware.js';
import type { RouteFn, MatchedRoute, RouteMatcher, MakeUrlOptions, MakeSignedUrlOptions } from '../types/route.js';
export declare class Router extends LookupStore {
    #private;
    routes: (Route | RouteResource | RouteGroup | BriskRoute)[];
    usingDomains: boolean;
    matchers: Matchers;
    constructor(app: Application<any, any>, encryption: Encryption, qsParser: Qs);
    use(middleware: LazyImport<MiddlewareAsClass>[]): this;
    named<NamedMiddleware extends Record<string, LazyImport<MiddlewareAsClass>>>(collection: NamedMiddleware): { [K in keyof NamedMiddleware]: <Args extends import("../types/middleware.js").GetMiddlewareArgs<import("../types/base.js").UnWrapLazyImport<NamedMiddleware[K]>>>(...args: Args) => {
        name: K;
        args: Args[0];
    } & ParsedGlobalMiddleware; };
    route(pattern: string, methods: string[], handler: string | RouteFn): Route;
    any(pattern: string, handler: string | RouteFn): Route;
    get(pattern: string, handler: string | RouteFn): Route;
    post(pattern: string, handler: string | RouteFn): Route;
    put(pattern: string, handler: string | RouteFn): Route;
    patch(pattern: string, handler: string | RouteFn): Route;
    delete(pattern: string, handler: string | RouteFn): Route;
    group(callback: () => void): RouteGroup;
    resource(resource: string, controller: string): RouteResource;
    shallowResource(resource: string, controller: string): RouteResource;
    on(pattern: string): BriskRoute;
    where(param: string, matcher: RouteMatcher | string | RegExp): this;
    commit(): void;
    match(url: string, method: string, hostname?: string | null): null | MatchedRoute;
    makeUrl(routeIdentifier: string, params?: any[] | Record<string, any>, options?: MakeUrlOptions): string;
    makeSignedUrl(routeIdentifier: string, params?: any[] | Record<string, any>, options?: MakeSignedUrlOptions): string;
}
